@@ -48,13 +48,15 @@ class KiloSortSession(object):
 		"""
 		self.fname_root = fname_root
 		import os
-		for d, _, f in os.walk(fname_root):
+		for d, c, f in os.walk(fname_root):
 			for ff in f:
-				if 'spike_times.npy' in ff:
-					self.fname_root = d
+				if '.' not in c: # ignore hidden directories
+					if 'spike_times.npy' in ff:
+						self.fname_root = d
 		self.cluster_id = None
 		self.spk_clusters = None
 		self.spk_times = None
+		self.good_KS_ids = []
 
 	def load(self):
 		"""
@@ -68,6 +70,7 @@ class KiloSortSession(object):
 			so user defined (has labels like 'good', 'MUA', 'noise' etc)
 		"""
 		import os
+		import pandas as pd
 		dtype = {'names': ('cluster_id', 'group'), 'formats': ('i4', 'S10')}
 		# One of these (cluster_groups.csv or cluster_group.tsv) is from kilosort and the other from kilosort2
 		# and is updated by the user when doing cluster assignment in phy (or whatever)
@@ -76,6 +79,17 @@ class KiloSortSession(object):
 			self.cluster_id, self.group = np.loadtxt(os.path.join(self.fname_root, 'cluster_groups.csv'), unpack=True, skiprows=1, dtype=dtype)
 		if os.path.exists(os.path.join(self.fname_root, 'cluster_group.tsv')):
 			self.cluster_id, self.group = np.loadtxt(os.path.join(self.fname_root, 'cluster_group.tsv'), unpack=True, skiprows=1, dtype=dtype)
+		
+		# HWPD 20200527 
+		# load cluster_info file and add X co-ordinate to it
+		if os.path.exists(os.path.join(self.fname_root, 'cluster_info.tsv')): # load cluster_info file and add X co-ordinate to it
+			self.cluster_info = pd.read_csv(os.path.join(self.fname_root, 'cluster_info.tsv'),"\t")
+			if os.path.exists(os.path.join(self.fname_root, 'channel_positions.npy')) and os.path.exists(os.path.join(self.fname_root, 'channel_map.npy')):
+				chXZ = np.load(os.path.join(self.fname_root, 'channel_positions.npy'))
+				chMap = np.load(os.path.join(self.fname_root, 'channel_map.npy'))
+				chID = np.asarray([np.argmax(chMap==x) for x in self.cluster_info.ch.values])
+				self.cluster_info['chanX'] = chXZ[chID,0]
+				self.cluster_info['chanY'] = chXZ[chID,1]
 		"""
 		Output some information to the user if self.cluster_id is still None
 		it implies that data has not been sorted / curated
@@ -89,7 +103,7 @@ class KiloSortSession(object):
 		if os.path.exists(os.path.join(self.fname_root, 'cluster_KSLabel.tsv')):
 			self.ks_cluster_id, self.ks_group = np.loadtxt(os.path.join(self.fname_root, 'cluster_KSLabel.tsv'), unpack=True, skiprows=1, dtype=dtype)
 		self.spk_clusters = np.squeeze(np.load(os.path.join(self.fname_root, 'spike_clusters.npy')))
-		self.spk_times    = np.squeeze(np.load(os.path.join(self.fname_root, 'spike_times.npy')))
+		self.spk_times    = np.squeeze(np.load(os.path.join(self.fname_root, 'spike_times.npy')))		
 
 	def removeNoiseClusters(self):
 		"""
@@ -100,6 +114,14 @@ class KiloSortSession(object):
 			for id_group in zip(self.cluster_id, self.group):
 				if 'noise' not in id_group[1].decode() and 'mua' not in id_group[1].decode():
 					self.good_clusters.append(id_group[0])
+	
+	def removeKSNoiseClusters(self):
+		"""
+		Removes "noise" and "mua" clusters from the kilosort labelled stuff
+		"""
+		for cluster_id, kslabel in zip(self.ks_cluster_id, self.ks_group):
+			if 'good' in kslabel.decode():
+				self.good_KS_ids.append(cluster_id)
 
 
 class OpenEphysBase(object):
@@ -144,7 +166,7 @@ class OpenEphysBase(object):
 		# Loads a kilosort session
 		kilodata = KiloSortSession(self.pname_root) # pname_root gets walked through and over-written with correct location of kiolsort data
 		kilodata.load()
-		kilodata.removeNoiseClusters()
+		kilodata.removeKSNoiseClusters()
 		self.kilodata = kilodata
 
 	def __loadSettings__(self):
@@ -159,13 +181,53 @@ class OpenEphysBase(object):
 	def __loaddata__(self, **kwargs):
 		self.load(self.pname_root, **kwargs) # some knarly hack
 
-	def plotXCorrs(self):
+	def prepareMaps(self, **kwargs):
+		"""Initialises a MapCalcsGeneric object by providing it with positional and
+		spiking data.
+
+		I don't like the name of this method but it is useful to be able to separate
+		out the preparation of the MapCalcsGeneric object as there are two major uses;
+		actually plotting the maps and/ or extracting data from them without plotting
+		"""
+		if self.kilodata is None:
+			self.loadKilo()
+		if ( 'ppm' in kwargs.keys() ):
+			ppm = kwargs['ppm']
+		else:
+			ppm = 400
+		from ephysiopy.common.ephys_generic import PosCalcsGeneric, MapCalcsGeneric
+		if self.xy is None:
+			self.__loaddata__(**kwargs)
+		posProcessor = PosCalcsGeneric(self.xy[:,0], self.xy[:,1], ppm, jumpmax=self.jumpmax)
+		import os
+		self.__loadSettings__()
+		xy, hdir = posProcessor.postprocesspos(self.settings.tracker_params)
+		self.hdir = hdir
+		spk_times = (self.kilodata.spk_times.T / 3e4) + self.recording_start_time
+		if 'plot_type' in kwargs:
+			plot_type = kwargs['plot_type']
+		else:
+			plot_type = 'map'
+		mapiter = MapCalcsGeneric(xy, np.squeeze(hdir), posProcessor.speed, self.xyTS, spk_times, plot_type, **kwargs)
+		if 'cluster' in kwargs:
+			if type(kwargs['cluster']) == int:
+				mapiter.good_clusters = np.intersect1d([kwargs['cluster']], self.kilodata.good_clusters)
+
+			else:
+				mapiter.good_clusters = np.intersect1d(kwargs['cluster'], self.kilodata.good_clusters)
+		else:
+			mapiter.good_clusters = self.kilodata.good_clusters
+		mapiter.spk_clusters = self.kilodata.spk_clusters
+		self.mapiter = mapiter
+		return mapiter
+
+	def plotXCorrs(self, **kwargs):
 		if self.kilodata is None:
 			self.loadKilo()
 		from ephysiopy.common.ephys_generic import SpikeCalcsGeneric
 		corriter = SpikeCalcsGeneric(self.kilodata.spk_times)
 		corriter.spk_clusters = self.kilodata.spk_clusters
-		corriter.plotAllXCorrs(self.kilodata.good_clusters)
+		corriter.plotAllXCorrs(self.kilodata.good_KS_ids)
 
 	def plotPos(self, jumpmax=None, show=True, **kwargs):
 		"""
@@ -194,10 +256,17 @@ class OpenEphysBase(object):
 		posProcessor = PosCalcsGeneric(self.xy[:,0], self.xy[:,1], ppm=300, cm=True, jumpmax=jumpmax)
 		xy, hdir = posProcessor.postprocesspos(self.settings.tracker_params)
 		self.hdir = hdir
+		if 'saveas' in kwargs:
+			saveas = kwargs['saveas']
+			plt.plot(xy[0], xy[1])
+			plt.gca().invert_yaxis()
+			plt.axis('off')
+			plt.savefig(saveas)
 		if show:
 			plt.plot(xy[0], xy[1])
 			plt.gca().invert_yaxis()
-			plt.show()
+			ax = plt.gca()
+			return ax, xy
 		return xy
 
 	def plotMaps(self, plot_type='map', **kwargs):
@@ -231,33 +300,15 @@ class OpenEphysBase(object):
 		in one figure window
 
 		"""
-		if self.kilodata is None:
-			self.loadKilo()
-		if ( 'ppm' in kwargs.keys() ):
-			ppm = kwargs['ppm']
-		else:
-			ppm = 400
-		from ephysiopy.common.ephys_generic import PosCalcsGeneric, MapCalcsGeneric
-		if self.xy is None:
-			self.__loaddata__(**kwargs)
-		posProcessor = PosCalcsGeneric(self.xy[:,0], self.xy[:,1], ppm, jumpmax=self.jumpmax)
-		import os
-		self.__loadSettings__()
-		xy, hdir = posProcessor.postprocesspos(self.settings.tracker_params)
-		self.hdir = hdir
-		spk_times = (self.kilodata.spk_times.T / 3e4) + self.recording_start_time
-		mapiter = MapCalcsGeneric(xy, np.squeeze(hdir), posProcessor.speed, self.xyTS, spk_times, plot_type, **kwargs)
-		if 'cluster' in kwargs:
-			if type(kwargs['cluster']) == int:
-				mapiter.good_clusters = np.intersect1d([kwargs['cluster']], self.kilodata.good_clusters)
+		self.prepareMaps(**kwargs)
+		if 'clusters' in kwargs:
+			if type(kwargs['clusters']) == int:
+				self.mapiter.good_clusters = np.intersect1d([kwargs['clusters']], self.kilodata.good_clusters)
 
 			else:
-				mapiter.good_clusters = np.intersect1d(kwargs['cluster'], self.kilodata.good_clusters)
-		else:
-			mapiter.good_clusters = self.kilodata.good_clusters
-		mapiter.spk_clusters = self.kilodata.spk_clusters
-		self.mapiter = mapiter
-		mapiter.plotAll()
+				self.mapiter.good_clusters = np.intersect1d(kwargs['clusters'], self.kilodata.good_clusters)
+		
+		self.mapiter.plotAll()
 
 	def plotMapsOneAtATime(self, plot_type='map', **kwargs):
 		"""
@@ -269,7 +320,7 @@ class OpenEphysBase(object):
 			* 'path' - just spikes on path
 			* 'both' - both of the above
 			* 'all' - both spikes on path, ratemap & SAC plotted
-		Keyword args:
+		kwargs :
 		* 'ppm' - Integer denoting pixels per metre where lower values = more bins in ratemap / SAC
 		* 'clusters' - int or list of ints describing which clusters to plot
 		* 'save_grid_summary_location' - bool; if True the dictionary returned from gridcell.SAC.getMeasures is saved for each cluster
@@ -301,7 +352,6 @@ class OpenEphysBase(object):
 			mapiter.good_clusters = self.kilodata.good_clusters
 		mapiter.spk_clusters = self.kilodata.spk_clusters
 		self.mapiter = mapiter
-		# mapiter.plotAll()
 		[ print("") for cluster in mapiter ]
 
 	def plotEEGPower(self, channel=0):
@@ -315,7 +365,7 @@ class OpenEphysBase(object):
 
 		See Also
 		-----
-		EEGCalcsGeneric.plotPowerSpectrum
+		ephysiopy.common.ephys_generic.EEGCalcsGeneric.plotPowerSpectrum()
 		"""
 		from ephysiopy.common.ephys_generic import EEGCalcsGeneric
 		if self.rawData is None:
@@ -355,6 +405,11 @@ class OpenEphysBase(object):
 		ax.set_ylabel('Frequency(Hz)')
 
 	def plotPSTH(self):
+		"""Plots the peri-stimulus time histogram for all the 'good' clusters
+
+		Given some data has been recorded in the ttl channel, this method will plot
+		the PSTH for each 'good' cluster and just keep spitting out figure windows
+		"""
 		import os
 		self.__loadSettings__()
 		self.settings.parseStimControl()
@@ -400,7 +455,7 @@ class OpenEphysBase(object):
 			print("Cluster {}".format(cluster))
 
 class OpenEphysNPX(OpenEphysBase):
-	"""docstring for OpenEphysNPX"""
+	"""The main class for dealing with data recorded using Neuropixels probes under openephys."""
 	def __init__(self, pname_root):
 		super().__init__(pname_root)
 		self.path2PosData = None
@@ -409,14 +464,19 @@ class OpenEphysNPX(OpenEphysBase):
 
 	def load(self, pname_root=None, experiment_name='experiment1', recording_name='recording1'):
 		"""
-		Loads data recorded in the OE 'flat' binary format
-		See https://open-ephys.atlassian.net/wiki/spaces/OEW/pages/166789121/Flat+binary+format for more
+		Loads data recorded in the OE 'flat' binary format.
 
 		Parameters
 		----------
-		pname_root - str - the top level directory, typically in form of YYYY-MM-DD_HH-MM-SS
+		pname_root : str
+			The top level directory, typically in form of YYYY-MM-DD_HH-MM-SS
 
-		recording_name - str - pretty obvious but this is also the directory immediately beneath pname_root
+		recording_name : str
+			The directory immediately beneath pname_root
+
+		See Also
+		--------
+		See https://open-ephys.atlassian.net/wiki/spaces/OEW/pages/166789121/Flat+binary+format
 		"""
 		self.isBinary = True
 		import os
@@ -431,15 +491,16 @@ class OpenEphysNPX(OpenEphysBase):
 
 		for d, c, f in os.walk(pname_root):
 			for ff in f:
-				if 'data_array.npy' in ff:
-					self.path2PosData = os.path.join(d)
-				if 'continuous.dat' in ff:
-					if APdata_match.search(d):
-						self.path2APdata = os.path.join(d)
-					if LFPdata_match.search(d):
-						self.path2LFPdata = os.path.join(d)
-				if 'sync_messages.txt' in ff:
-					sync_message_file = os.path.join(d, 'sync_messages.txt')
+				if '.' not in c: # ignore hidden directories
+					if 'data_array.npy' in ff:
+						self.path2PosData = os.path.join(d)
+					if 'continuous.dat' in ff:
+						if APdata_match.search(d):
+							self.path2APdata = os.path.join(d)
+						if LFPdata_match.search(d):
+							self.path2LFPdata = os.path.join(d)
+					if 'sync_messages.txt' in ff:
+						sync_message_file = os.path.join(d, 'sync_messages.txt')
 
 		if self.path2PosData is not None:
 			pos_data = np.load(os.path.join(self.path2PosData, 'data_array.npy'))
@@ -465,7 +526,75 @@ class OpenEphysNPX(OpenEphysBase):
 			recording_start_time = self.xyTS[0]
 		self.recording_start_time = recording_start_time
 		self.ts = np.arange(recording_start_time, trial_length+recording_start_time, 1.0 / ap_sample_rate)
+		
+	def loadLite(self, pname_root=None, experiment_name='experiment1', recording_name='recording1'):
+		# HWPD 20200529
+		"""
+		Loads data recorded in the OE 'flat' binary format but doesn't require the large continuous.dat file
 
+		Parameters
+		----------
+		pname_root : str
+			The top level directory, typically in form of YYYY-MM-DD_HH-MM-SS
+
+		recording_name : str
+			The directory immediately beneath pname_root
+
+		See Also
+		--------
+		See https://open-ephys.atlassian.net/wiki/spaces/OEW/pages/166789121/Flat+binary+format
+		"""
+		self.isBinary = True
+		import os
+		import re
+		APdata_match = re.compile('Neuropix-PXI-[0-9][0-9][0-9].0')
+		LFPdata_match = re.compile('Neuropix-PXI-[0-9][0-9][0-9].1')
+		sync_message_file = None
+		self.recording_start_time = None
+
+		if pname_root is None:
+			pname_root = self.pname_root
+
+		for d, c, f in os.walk(pname_root):
+			for ff in f:
+				if '.' not in c: # ignore hidden directories
+					if 'data_array.npy' in ff:
+						self.path2PosData = os.path.join(d)
+					if 'spike_times.npy' in ff: # changed from continuous.dat
+						if APdata_match.search(d):
+							self.path2APdata = os.path.join(d)
+						if LFPdata_match.search(d):
+							self.path2LFPdata = os.path.join(d)
+					if 'sync_messages.txt' in ff:
+						sync_message_file = os.path.join(d, 'sync_messages.txt')
+
+		if self.path2PosData is not None:
+			pos_data = np.load(os.path.join(self.path2PosData, 'data_array.npy'))
+			self.xy = pos_data[:,0:2]
+			pos_ts = np.load(os.path.join(self.path2PosData, 'timestamps.npy'))
+			self.xyTS = pos_ts / 30.0 / 1000.0
+
+		ap_sample_rate = 30000
+		n_channels = 384
+		spk_times = np.squeeze(np.load(os.path.join(self.path2APdata, 'spike_times.npy')))
+		last_spike_time = spk_times.max() / ap_sample_rate
+		#trial_length = self.__calcTrialLengthFromBinarySize__(os.path.join(self.path2APdata, 'continuous.dat'), n_channels, ap_sample_rate)
+		# Load the start time from the sync_messages file
+		if sync_message_file is not None:
+			with open(sync_message_file, 'r') as f:
+				sync_strs = f.read()
+			sync_lines = sync_strs.split('\n')
+			for line in sync_lines:
+				if 'subProcessor: 0' in line:
+					idx = line.find('start time: ')
+					start_val = line[idx + len('start time: '):-1]
+					tmp = start_val.split('@')
+					recording_start_time = float(tmp[0]) / float(tmp[1][0:-1])
+		else:
+			recording_start_time = self.xyTS[0]
+		self.recording_start_time = recording_start_time
+		self.ts = np.arange(recording_start_time, last_spike_time, 1.0 / ap_sample_rate)
+		
 	def __calcTrialLengthFromBinarySize__(self, path2file:str, n_channels=384, sample_rate=30000):
 		"""
 		Returns the time taken to run the trial (in seconds) based on the size of
@@ -554,10 +683,13 @@ class OpenEphysNPX(OpenEphysBase):
 		meanfreq_powerAx.set_xlabel('Mean freq. band power(dB)')
 		meanfreq_powerAx.legend(bbox_to_anchor=(0., 1.02, 1., .102), loc='lower left', mode='expand',
 			fontsize='x-small', ncol=1)
+		if 'saveas' in kwargs:
+			saveas = kwargs['saveas']
+			plt.savefig(saveas)
 		plt.show()
 
-	def plotPos(self, jumpmax=None, show=True):
-		super().plotPos(jumpmax, show)
+	def plotPos(self, jumpmax=None, show=True, **kwargs):
+		super().plotPos(jumpmax, show, **kwargs)
 
 	def plotMaps(self, plot_type='map', **kwargs):
 		super().plotMaps(plot_type, **kwargs)
@@ -565,20 +697,20 @@ class OpenEphysNPX(OpenEphysBase):
 	def plotMapsOneAtATime(self, plot_type='map', **kwargs):
 		super().plotMapsOneAtATime(plot_type, **kwargs)
 
-	def plotEEGPower(self, channel=0):
-		super().plotEEGPower(channel)
+	def plotEEGPower(self, channel=0, **kwargs):
+		super().plotEEGPower(channel, **kwargs)
 
-	def plotSpectrogram(self, nSeconds=30, secsPerBin=2, ax=None, ymin=0, ymax=250):
-		super().plotSpectrogram(nSeconds, secsPerBin, ax, ymin, ymax)
+	def plotSpectrogram(self, nSeconds=30, secsPerBin=2, ax=None, ymin=0, ymax=250, **kwargs):
+		super().plotSpectrogram(nSeconds, secsPerBin, ax, ymin, ymax, **kwargs)
 
-	def plotPSTH(self):
-		super().plotPSTH()
+	def plotPSTH(self, **kwargs):
+		super().plotPSTH(**kwargs)
 
-	def plotEventEEG(self):
-		super().plotEventEEG()
+	def plotEventEEG(self, **kwargs):
+		super().plotEventEEG(**kwargs)
 
-	def plotWaves(self):
-		super().plotWaves()
+	def plotWaves(self, **kwargs):
+		super().plotWaves(**kwargs)
 
 class OpenEphysNWB(OpenEphysBase):
 	"""
@@ -594,6 +726,7 @@ class OpenEphysNWB(OpenEphysBase):
 		self.rawData = None # np.array holding the raw, continuous recording
 		self.recording_name = None # the recording name inside the nwb file ('recording0', 'recording1', etc)
 		self.isBinary = False
+		self.xy = None
 
 	def load(self, pname_root: None, session_name=None, recording_name=None, loadraw=False, loadspikes=False, savedat=False):
 		"""
@@ -632,14 +765,22 @@ class OpenEphysNWB(OpenEphysBase):
 			if recording_name is None:
 				recording_name = 'recording1'
 			self.recording_name = recording_name
-		self.xy = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['binary1']['data'])
+		try:
+			self.xy = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['binary1']['data'])
 
-		self.xyTS = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['binary1']['timestamps'])
-		self.xyTS = self.xyTS - (self.xy[:,2] / 1e6)
-		self.xy = self.xy[:,0:2]
-		# TTL data...
-		self.ttl_data = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['ttl1']['data'])
-		self.ttl_timestamps = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['ttl1']['timestamps'])
+			self.xyTS = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['binary1']['timestamps'])
+			self.xyTS = self.xyTS - (self.xy[:,2] / 1e6)
+			self.xy = self.xy[:,0:2]
+		except:
+			self.xy = None
+			self.xyTS = None
+		try:
+			# TTL data...
+			self.ttl_data = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['ttl1']['data'])
+			self.ttl_timestamps = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['ttl1']['timestamps'])
+		except:
+			self.ttl_data = None
+			self.ttl_timestamps = None
 
 		# ...everything else
 		try:
@@ -711,7 +852,7 @@ class OpenEphysNWB(OpenEphysBase):
 
 class SpkTimeCorrelogram(object):
 	def __init__(self, clusters, spk_times, spk_clusters):
-		from dacq2py import spikecalcs
+		from ephysiopy.dacq2py import spikecalcs
 		self.SpkCalcs = spikecalcs.SpikeCalcs()
 		self.clusters = clusters
 		self.spk_times = spk_times
